@@ -9,7 +9,7 @@ bilibili_api.login
 """
 
 import json
-import re
+import httpx
 from typing import Union
 import uuid
 import hashlib
@@ -29,8 +29,7 @@ import os
 import tempfile
 import time
 import base64
-from Crypto.PublicKey import RSA
-from Crypto.Cipher import PKCS1_v1_5
+import rsa
 
 API = get_api("login")
 
@@ -145,7 +144,7 @@ def login_with_qrcode(root=None):
 def update_qrcode():
     global login_key, qrcode_image
     api = API["qrcode"]["get_qrcode_and_token"]
-    qrcode_login_data = sync(request("GET", api["url"]))
+    qrcode_login_data = json.loads(httpx.get(api["url"]).text)["data"]
     login_key = qrcode_login_data["oauthKey"]
     qrcode = qrcode_login_data["url"]
     qrcode_image = make_qrcode(qrcode)
@@ -158,10 +157,12 @@ def update_qrcode():
 
 
 def encrypt(_hash, key, password):
-    encryptor = PKCS1_v1_5.new(RSA.importKey(bytes(key, "utf-8")))
-    return str(
-        base64.b64encode(encryptor.encrypt(bytes(_hash + password, "utf-8"))), "utf-8"
+    rsa_key = rsa.PublicKey.load_pkcs1_openssl_pem(key.encode("utf-8"))
+    data = str(
+        base64.b64encode(rsa.encrypt(bytes(_hash + password, "utf-8"), rsa_key)),
+        "utf-8",
     )
+    return data
 
 
 def get_geetest():
@@ -193,8 +194,8 @@ def login_with_password(username: str, password: str):
         Union[Credential, Check]: 如果需要验证，会返回 [`Check`](#check) 类，否则返回 `Credential` 类。
     """
     api_token = API["password"]["get_token"]
-    sess = get_session()
-    token_data = json.loads(sync(sess.get(api_token["url"])).text)
+    sess = httpx.Client()
+    token_data = json.loads(sess.get(api_token["url"]).text)
     hash_ = token_data["data"]["hash"]
     key = token_data["data"]["key"]
     final_password = encrypt(hash_, key, password)
@@ -224,18 +225,16 @@ def login_with_password(username: str, password: str):
     hasher = hashlib.md5(md5_string.encode(encoding="utf-8"))
     datas["sign"] = hasher.hexdigest()
     login_data = json.loads(
-        sync(
-            sess.request(
-                "POST",
-                login_api["url"],
-                data=datas,
-                headers={
-                    "Content-Type": "application/x-www-form-urlencoded",
-                    "User-Agent": "Mozilla/5.0",
-                    "Referer": "https://passport.bilibili.com/login",
-                },
-                cookies={"buvid3": str(uuid.uuid1())},
-            )
+        sess.request(
+            "POST",
+            login_api["url"],
+            data=datas,
+            headers={
+                "Content-Type": "application/x-www-form-urlencoded",
+                "User-Agent": "Mozilla/5.0",
+                "Referer": "https://passport.bilibili.com/login",
+            },
+            cookies={"buvid3": str(uuid.uuid1())},
         ).text
     )
     if login_data["code"] == 0:
